Module src

Module src 

Source Address

Structs

SrcSpec
Source Address

Type Aliases

R
Register SRC reader
SrcR
Field SRC reader - 31:0] Source Address: The 32-bit source address parameters specify the starting byte address of the source . If SAM is set to FIFO mode then the user should program the Source address to be aligned to the value specified by the OPT.FWID field. No errors are recognized here but TC will assert error if this is not true.
SrcW
Field SRC writer - 31:0] Source Address: The 32-bit source address parameters specify the starting byte address of the source . If SAM is set to FIFO mode then the user should program the Source address to be aligned to the value specified by the OPT.FWID field. No errors are recognized here but TC will assert error if this is not true.
W
Register SRC writer